// src/middleware/errorMiddleware.js

// Basic error handling middleware
// Catches errors passed via next(error) from route handlers or other middleware
const errorHandler = (err, req, res, next) => {
    console.error("Unhandled Error:", err.stack || err); // Log the full error stack

    // Default error status and message
    let statusCode = err.statusCode || 500; // Use specific status code if available, otherwise default to 500
    let message = err.message || 'Interner Serverfehler.';

    // Handle specific error types if needed
    if (err.name === 'ValidationError') { // Example for a potential validation error library
        statusCode = 400;
        message = `Validierungsfehler: ${err.message}`;
    } else if (err.code === '23505') { // Handle PostgreSQL unique violation errors
         statusCode = 409; // Conflict
         message = `Konflikt: Ein Eintrag mit diesen Daten existiert bereits. (${err.detail})`;
    } else if (err.code === '23503') { // Handle PostgreSQL foreign key violation
        statusCode = 400; // Bad Request or Conflict (409) might be appropriate
        message = `Referenzfehler: Der verknüpfte Eintrag existiert nicht. (${err.detail})`;
    }
    // Add more specific error handling as needed

    // Send the error response
    res.status(statusCode).json({
        message: message,
        // Optionally include stack trace in development environment
        stack: process.env.NODE_ENV === 'development' ? err.stack : undefined,
    });
};

module.exports = errorHandler;
