// src/routes/matchRoutes.js
const express = require('express');
const matchController = require('../controllers/matchController'); // Import actual controller
const { authenticateToken, authorizeRole, authorizeRoles } = require('../middleware/authMiddleware');

const router = express.Router();

// --- Publicly Accessible GET Routes ---

// GET /api/matches - Get all matches (filtered by tournamentId or gets active ones)
router.get('/', matchController.getAllMatches);

// GET /api/matches/:id - Get details of a specific match
router.get('/:id', matchController.getMatchById);


// --- Admin Only Routes ---

// POST /api/matches - Manually add a match (Admin only)
router.post('/', authenticateToken, authorizeRole('admin'), matchController.createMatch);

// PUT /api/matches/:id - Update match details (e.g., schedule, table) (Admin only)
router.put('/:id', authenticateToken, authorizeRole('admin'), matchController.updateMatch);

// DELETE /api/matches/:id - Delete a match (Admin only)
router.delete('/:id', authenticateToken, authorizeRole('admin'), matchController.deleteMatch);

// GET /api/matches/export/pdf - Export matches (current, future, past) as PDF (Admin only)
// Note: Might conflict with GET /:id if not handled carefully
router.get('/export/pdf', authenticateToken, authorizeRole('admin'), matchController.exportMatchesPdf);

// POST /api/matches/generate-bracket - Generate tournament bracket (Admin only)
router.post('/generate-bracket', authenticateToken, authorizeRole('admin'), matchController.generateBracket);


// --- Admin or Referee Routes ---

// POST /api/matches/:id/score - Enter/Update scores for a match (Admin or Referee)
router.post('/:id/score', authenticateToken, authorizeRoles('admin', 'referee'), matchController.updateMatchScore);


module.exports = router;
