// src/routes/playerRoutes.js
const express = require('express');
const playerController = require('../controllers/playerController'); // Import the actual controller
const { authenticateToken, authorizeRole, authorizeRoles } = require('../middleware/authMiddleware');

const router = express.Router();

// --- Publicly Accessible GET Routes ---

// GET /api/players - Get all players (with optional search)
router.get('/', playerController.getAllPlayers);

// GET /api/players/:id - Get a specific player
router.get('/:id', playerController.getPlayerById);


// --- Admin only routes ---

// POST /api/players - Add a new player (Admin only)
router.post('/', authenticateToken, authorizeRole('admin'), playerController.createPlayer);

// PUT /api/players/:id - Update a player (Admin only)
router.put('/:id', authenticateToken, authorizeRole('admin'), playerController.updatePlayer);

// DELETE /api/players/:id - Remove a player (Admin only)
router.delete('/:id', authenticateToken, authorizeRole('admin'), playerController.deletePlayer);

// POST /api/players/import - Import players from CSV (Admin only)
// TODO: Add multer middleware here for file upload when implemented
router.post('/import', authenticateToken, authorizeRole('admin'), playerController.importPlayers);

// GET /api/players/export - Export players to CSV (Admin only)
// Note: Might conflict with GET /:id if not handled carefully in controller or route order
router.get('/export', authenticateToken, authorizeRole('admin'), playerController.exportPlayers);


module.exports = router;
