// src/routes/userRoutes.js
const express = require('express');
const userController = require('../controllers/userController');
const { authorizeRole } = require('../middleware/authMiddleware'); // Only admins manage users

const router = express.Router();

// All user management routes require admin privileges
router.use(authorizeRole('admin'));

// GET /api/users - Get all users
router.get('/', userController.getAllUsers);

// POST /api/users - Create a new user
router.post('/', userController.createUser);

// GET /api/users/:id - Get a single user by ID
router.get('/:id', userController.getUserById);

// PUT /api/users/:id - Update a user
router.put('/:id', userController.updateUser);

// DELETE /api/users/:id - Delete a user
router.delete('/:id', userController.deleteUser);

module.exports = router;
